## START: Set by rpmautospec
## (rpmautospec version 0.6.3)
## RPMAUTOSPEC: autorelease, autochangelog
%define autorelease(e:s:pb:n) %{?-p:0.}%{lua:
    release_number = 1;
    base_release_number = tonumber(rpm.expand("%{?-b*}%{!?-b:1}"));
    print(release_number + base_release_number - 1);
}%{?-e:.%{-e*}}%{?-s:.%{-s*}}%{!?-n:%{?dist}}
## END: Set by rpmautospec

Name:           imagej
Version:        1.54k
Release:        %autorelease
Summary:        Image Processing and Analysis in Java

# From https://imagej.nih.gov/ij/disclaimer.html:
#   ImageJ was developed at the National Institutes of Health by an employee of
#   the Federal Government in the course of his official duties. Pursuant to
#   Title 17, Section 105 of the United States Code, this software is not
#   subject to copyright protection and is in the public domain. ImageJ is an
#   experimental system. NIH assumes no responsibility whatsoever for its use
#   by other parties, and makes no guarantees, expressed or implied, about its
#   quality, reliability, or any other characteristic.
# https://gitlab.com/fedora/legal/fedora-license-data/-/commit/b216f9bcb1c3195b4ddb14674d95e299f669903a
License:        LicenseRef-Fedora-Public-Domain
URL:            https://imagej.net/ij/index.html
Source0:        https://imagej.net/ij/download/src/ij%(echo '%{version}' | tr -d .)-src.zip
Source1:        imagej.desktop
Source2:        https://imagej.net/ij/macros/macros.zip
Source3:        https://imagej.net/ij/download/linux/unix-script.txt
Source4:        imagej.png

BuildArch:      noarch
ExclusiveArch:  %{java_arches} noarch

# Do not copy class files.
Patch:          imagej-1.54g-do-not-copy-class-files.patch
# Modify imagej.sh (as intended by upstream) for Fedora compatibility.
Patch:          imagej-1.53r-unix-script.patch
# Set javac source / target version to 1.8 to fix building with Java 11.
Patch:          imagej-1.53r-source-target-version.patch

BuildRequires:  ant
BuildRequires:  desktop-file-utils

BuildRequires:  jpackage-utils
BuildRequires:  java-devel

Requires:       jpackage-utils
# Require java-devel, not only java, for plugins build
Requires:       java-devel

# We no longer package javadoc documentation because it has guidelines issues
# pertaining to bundled and pre-minified JavaScript and CSS.  See
# https://bugzilla.redhat.com/show_bug.cgi?id=2006555 and the linked
# “packaging” mailing list discussion for similar issues in documentation
# generated by Sphinx and Doxygen.
Obsoletes:      imagej-javadoc < 1.53r-1

%description
ImageJ is a public domain Java image processing program. It can display, edit,
analyze a wide variety of image data, including image sequences. Imagej can be
used for quantitative analysis of engineering and scientific image data.


%prep
%autosetup -c -N
unzip -qq -u '%{SOURCE2}'
cp -p '%{SOURCE3}' ./imagej.sh

# Erase binary and useless files
rm -rvf macros/.FBC* macros/build.xml __MACOSX
# Strip out any bundled pre-compiled class or jar files:
find . \( -name '*.class' -o -name '*.jar' \) -print -delete
# Fix permissions
find macros -type d -exec chmod -v 0755 '{}' '+'
find macros -type f -exec chmod -v 0644 '{}' '+'

%autopatch -p1
# Replace placeholders in our patched unix-script.txt/imagej.sh.
sed -r -i \
    -e 's#@JAVADIR@#%{_javadir}#' \
    -e 's#@PKGDATADIR@#%{_datadir}/imagej#' \
    imagej.sh

# Make sure the upstream version number is set correctly, and use the initial
# numeric <pkgrel> field of the Release as the BUILD.
%global pkgrel %(echo '%{release}' | sed -r 's/[^[:digit:]].*$//')
sed -r -i \
    -e 's/(public static final String VERSION = )"[^"]+";/\1"%{version}";/' \
    -e 's/(public static final String BUILD = )"[^"]+";/\1"%{pkgrel}";/' \
    source/ij/ImageJ.java


%build
cd source
ant build
cd ..


%install
# install jar
install -p -m 0644 -D source/ij.jar '%{buildroot}%{_javadir}/imagej.jar'

# install icon
install -D -p -m 0644 -t '%{buildroot}%{_datadir}/pixmaps' '%{SOURCE4}'

# install data files and macros
install -D -p -m 0644 -t '%{buildroot}%{_datadir}/imagej' \
    source/build/about.jpg source/build/IJ_Props.txt
cp -rvp macros '%{buildroot}%{_datadir}/imagej/'

# install directories for luts and plugins
install -d '%{buildroot}%{_datadir}/imagej/luts' \
    '%{buildroot}%{_datadir}/imagej/plugins'
# install -p -m 0644 source/plugins/JavaScriptEvaluator.source \
#    '%%{buildroot}%%{_datadir}/imagej/plugins/JavaScriptEvaluator.java'

# install script
install -D -p imagej.sh '%{buildroot}%{_bindir}/imagej'

# desktop file
desktop-file-install --vendor=''                     \
       --dir=%{buildroot}%{_datadir}/applications/   \
       %{SOURCE1}


%files
%doc source/aREADME.txt source/release-notes.html

%{_javadir}/imagej.jar

%{_datadir}/imagej/
%{_datadir}/applications/imagej.desktop
%{_datadir}/pixmaps/imagej.png

%{_bindir}/imagej


%changelog
## START: Generated by rpmautospec
* Tue Sep 17 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 1.54k-1
- Update to 1.54k (close RHBZ#2292095)

* Thu Jul 18 2024 Fedora Release Engineering <releng@fedoraproject.org> - 1.54i-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_41_Mass_Rebuild

* Mon Mar 04 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 1.54i-1
- Update to 1.54i (close RHBZ#2267596)

* Tue Feb 27 2024 Jiri Vanek <jvanek@redhat.com> - 1.54h-4
- Rebuilt for java-21-openjdk as system jdk

* Wed Jan 24 2024 Fedora Release Engineering <releng@fedoraproject.org> - 1.54h-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Sat Jan 20 2024 Fedora Release Engineering <releng@fedoraproject.org> - 1.54h-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Fri Dec 22 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 1.54h-1
- Update to 1.54h (close RHBZ#2254747)

* Thu Oct 19 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 1.54g-1
- Update to 1.54g (close RHBZ#2244933)

* Thu Jul 20 2023 Fedora Release Engineering <releng@fedoraproject.org> - 1.54f-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_39_Mass_Rebuild

* Fri Jun 30 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 1.54f-1
- Update to 1.54f (close RHBZ#2212252)

* Mon Jun 05 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 1.54f-1
- Update to 1.54e (close RHBZ#2212252)

* Tue Apr 25 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 1.54d-1
- Update to 1.54d (close RHBZ#2183396)

* Fri Mar 10 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 1.54c-1
- Update to 1.54c (close RHBZ#2175999)

* Thu Jan 19 2023 Fedora Release Engineering <releng@fedoraproject.org> - 1.53v-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_38_Mass_Rebuild

* Thu Dec 29 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 1.53v-1
- Update to 1.53v (close RHBZ#2121261)

* Thu Jul 21 2022 Fedora Release Engineering <releng@fedoraproject.org> - 1.53r-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_37_Mass_Rebuild

* Fri Jul 08 2022 Jiri Vanek <jvanek@redhat.com> - 1.53r-4
- Rebuilt for Drop i686 JDKs

* Tue May 31 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 1.53r-3
- Make sure the upstream VERSION is set correctly
- Use the initial numeric <pkgrel> field of the Release as the BUILD

* Tue May 31 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 1.53r-2
- Fix regression in launcher script
- Symlinks called “*” will not be created when there are no shared plugins or
  luts
- Broken symlinks into shared directories will be removed
- Symlink changes will be printed to the terminal

* Mon May 30 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 1.53r-1
- Adjust versioning scheme
- Update to 1.53r (close RHBZ#1609549)
- Use HTTPS URLs
- Reduce macro indirection in the spec file
- Drop javadoc API documentation due to bundled JavaScript and CSS

* Sat Feb 05 2022 Jiri Vanek <jvanek@redhat.com> - 1.50-17.h
- Rebuilt for java-17-openjdk as system jdk

* Thu Jan 20 2022 Fedora Release Engineering <releng@fedoraproject.org> - 1.50-16.h
- Rebuilt for https://fedoraproject.org/wiki/Fedora_36_Mass_Rebuild

* Thu Jul 22 2021 Fedora Release Engineering <releng@fedoraproject.org> - 1.50-15.h
- Rebuilt for https://fedoraproject.org/wiki/Fedora_35_Mass_Rebuild

* Tue Jan 26 2021 Fedora Release Engineering <releng@fedoraproject.org> - 1.50-14.h
- Rebuilt for https://fedoraproject.org/wiki/Fedora_34_Mass_Rebuild

* Tue Oct 06 2020 Ankur Sinha <ankursinha AT fedoraproject DOT org> - 1.50-13.h
- Remove -dxx option from script (unsupported in java 11)
- Fix patch

* Tue Jul 28 2020 Fedora Release Engineering <releng@fedoraproject.org> - 1.50-12.h
- Rebuilt for https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Sun Jul 19 2020 Fabio Valentini <decathorpe@gmail.com> - 1.50-11.h
- Set javac source and target to 1.8 to fix Java 11 builds.

* Fri Jul 10 2020 Jiri Vanek <jvanek@redhat.com> - 1.50-10.h
- Rebuilt for JDK-11, see https://fedoraproject.org/wiki/Changes/Java11

* Wed Jan 29 2020 Fedora Release Engineering <releng@fedoraproject.org> - 1.50-9.h
- Rebuilt for https://fedoraproject.org/wiki/Fedora_32_Mass_Rebuild

* Thu Jul 25 2019 Fedora Release Engineering <releng@fedoraproject.org> - 1.50-8.h
- Rebuilt for https://fedoraproject.org/wiki/Fedora_31_Mass_Rebuild

* Fri Feb 01 2019 Fedora Release Engineering <releng@fedoraproject.org> - 1.50-7.h
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Fri Jul 13 2018 Fedora Release Engineering <releng@fedoraproject.org> - 1.50-6.h
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Wed Feb 07 2018 Fedora Release Engineering <releng@fedoraproject.org> - 1.50-5.h
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Thu Jan 11 2018 Igor Gnatenko <ignatenkobrain@fedoraproject.org> - 1.50-4.h
- Remove obsolete scriptlets

* Wed Jul 26 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.50-3.h
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.50-2.h
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Sat Mar 26 2016 Adam Huffman <bloch@verdurin.com> - 1.50-1.h
- Update to upstream release 1.50h

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 1.48-8.e
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Sat Jul 04 2015 Adam Huffman <bloch@verdurin.com> - 1.48-7.e
- Apply Java docdir fixes from Michael Simacek

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.48-6.e
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Wed Aug 13 2014 Adam Huffman <bloch@verdurin.com> - 1.48-5.e
- Fix bogus dates in changelog

* Wed Aug 13 2014 Adam Huffman <bloch@verdurin.com> - 1.48-4.e
- Fix desktop file to ensure application appears in menus

* Mon Jul 14 2014 Richard Hughes <richard@hughsie.com> - 1.48-3.e
- Ship a larger application icon so the metdata parser can include the app.

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.48-2.e
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Sat Oct 26 2013 Adam Huffman <bloch@verdurin.com> - 1.48-1.e
- Update to 1.48e

* Sun Aug 25 2013 Adam Huffman <bloch@verdurin.com> - 1.47-1.v
- Update to 1.47v

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.46-4.d
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.46-3.d
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Thu Jul 19 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.46-2.d
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Wed Jan 11 2012 Adam Huffman <verdurin@fedoraproject.org> - 1.46-1.d
- update to 1.45d

* Wed Feb 09 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.44-2.i
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Sat Oct 30 2010 Georget Fabien <fabien.georget@gmail.com> 1.44-1.i
- update to 1.44i
- create imagej.jar link

* Tue Sep 28 2010 Georget Fabien <fabien.georget@gmail.com> 1.44-1.h
- version 1.44h

* Fri Dec 11 2009 Georget Fabien <fabien.georget@gmail.com> 1.43-1.m
- version 1.43m

* Sat Nov 21 2009 Georget Fabien <fabien.georget@gmail.com> 1.43-0.5.j
- set build directory to {name}-{version}
- modify wrapper script
- add java-devel to requires

* Sun Nov 15 2009 Georget Fabien <fabien.georget@gmail.com> 1.43-0.4.j
- modify name from ImageJ to imagej
- modify wrapper script for fedora compatibility

* Tue Nov 10 2009 Georget Fabien <fabien.georget@gmail.com> 1.43-0.3.j
- get macros from  http://rsbweb.nih.gov/ij/macros/macros.zip
- get launch script from  http://rsb.info.nih.gov/ij/download/linux/unix-script.txt
- don't copy macros in the jar but in /usr/share/ImageJ/macros

* Tue Nov 10 2009 Georget Fabien <fabien.georget@gmail.com> 1.43-0.2.j
- change group to Application/Engineering
- change description
- add comments
- change version tag

* Sat Nov 8 2008 Georget Fabien <fabien.georget@gmail.com> 1.43-0.1
- Creation

## END: Generated by rpmautospec
